{% load staticfiles %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8" />
    <title>Django master</title>

    <link rel="stylesheet" href="{% static 'django_master/css/pure-min.css' %}" />
    <link rel="stylesheet" href="{% static 'django_master/css/side-menu.css' %}" />
    <link rel="stylesheet" href="{% static 'django_master/css/pure-theme.css' %}" />

    {% block extra_css %}{% endblock %}
</head>
<body>

    <div id="layout">
        {# Menu toggle #}
        <a href="#menu" id="menuLink" class="menu-link">
            {# Hamburger icon #}
            <span></span>
        </a>

        <div id="menu">
            {% include 'django_master/includes/_side_menu.html' %}
        </div>

        <div id="main">
            <div class="header">
                <h1>{% block page_title %}{% endblock %}</h1>
                <h2>{% block page_subtitle %}{% endblock %}</h2>
            </div>

            <div class="content">
                {% block content %}{% endblock %}

                {% comment %}
                <h2 class="content-subhead">How to use this layout</h2>
                <p>
                    To use this layout, you can just copy paste the HTML, along with the CSS in <a href="/css/layouts/side-menu.css" alt="Side Menu CSS">side-menu.css</a>, and the JavaScript in <a href="/js/ui.js">ui.js</a>. The JS file uses vanilla JavaScript to simply toggle an <code>active</code> class that makes the menu responsive.
                </p>

                <h2 class="content-subhead">Now Let's Speak Some Latin</h2>
                <p>
                    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
                </p>

                <div class="pure-g">
                    <div class="pure-u-1-4">
                        <img class="pure-img-responsive" src="http://farm3.staticflickr.com/2875/9069037713_1752f5daeb.jpg" alt="Peyto Lake">
                    </div>
                    <div class="pure-u-1-4">
                        <img class="pure-img-responsive" src="http://farm3.staticflickr.com/2813/9069585985_80da8db54f.jpg" alt="Train">
                    </div>
                    <div class="pure-u-1-4">
                        <img class="pure-img-responsive" src="http://farm6.staticflickr.com/5456/9121446012_c1640e42d0.jpg" alt="T-Shirt Store">
                    </div>
                    <div class="pure-u-1-4">
                        <img class="pure-img-responsive" src="http://farm8.staticflickr.com/7357/9086701425_fda3024927.jpg" alt="Mountain">
                    </div>
                </div>

                <h2 class="content-subhead">Try Resizing your Browser</h2>
                <p>
                    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.
                </p>
                {% endcomment %}
            </div>
        </div>
    </div>

    <script src="//ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js"></script>
    <script src="{% static 'django_master/js/ui.js' %}"></script>
    {% block extra_js %}{% endblock %}
</body>
</html>
