{% load url from future %}

<div class="pure-menu pure-menu-open">
    <a class="pure-menu-heading" href="{% url 'djangomaster_home' %}">Master</a>

    {% with selected_class="pure-menu-selected" %}

        <ul>
            <li {% ifequal menu_item 'home' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster_home' %}">Home</a>
            </li>

            <li class="menu-item-divided {% ifequal menu_item 'routes' %}{{selected_class}}{% endifequal %}">
                <a href="{% url 'djangomaster_routes' %}">Routes</a>
            </li>

            <li {% ifequal menu_item 'settings' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster_settings' %}">Settings</a>
            </li>
        </ul>

    {% endwith %}
</div>
